@@ -1,5 +1,5 @@
 package Geo::Coder::OpenCage;
-$Geo::Coder::OpenCage::VERSION = '0.02';
+$Geo::Coder::OpenCage::VERSION = '0.03';
 use strict;
 use warnings;
 
@@ -7,6 +7,7 @@ use JSON;
 use HTTP::Tiny;
 use URI;
 use Carp;
+use List::MoreUtils qw(none);
 
 sub new {
     my $class = shift;
@@ -30,14 +31,24 @@ sub geocode {
     my $self = shift;
     my %params = @_;
 
-    if (!$params{location}) {
+    if ($params{location}) {
+        $params{q} = delete $params{location};
+    }
+    else {
         croak "location is a required parameter for geocode()";
     }
 
+    for my $k (keys %params) {
+        if (none { $k eq $_ } qw(q country language)) {
+            warn "Unknown geocode parameter: $k";
+            delete $params{$k};
+        }
+    }
+
     my $URL = $self->{url}->clone();
     $URL->query_form(
         key => $self->{api_key},
-        q   => $params{location},
+        %params,
     );
 
     my $response = $self->{ua}->get($URL);
@@ -57,7 +68,7 @@ sub geocode {
 
 __END__
 
-=pod
+=encoding utf8
 
 =head1 NAME
 
@@ -65,17 +76,17 @@ Geo::Coder::OpenCage - Geocode addresses with the OpenCage Geocoder API
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 DESCRIPTION
 
 This module provides an interface to the OpenCage geocoding service.
 
+For full details on the API visit L<http://geocoder.opencagedata.com/api.html>.
+
 =head1 SYNOPSIS
 
-    my $Geocoder = Geo::Coder::OpenCage->new(
-        api_key => $my_api_key,
-    );
+    my $Geocoder = Geo::Coder::OpenCage->new(api_key => $my_api_key);
 
     my $result = $Geocoder->geocode(location => "Donostia");
 
@@ -83,9 +94,7 @@ This module provides an interface to the OpenCage geocoding service.
 
 =head2 new
 
-    my $Geocoder = Geo::Coder::OpenCage->new(
-        api_key => $my_api_key,
-    );
+    my $Geocoder = Geo::Coder::OpenCage->new(api_key => $my_api_key);
 
 You can get your API key from http://geocoder.opencagedata.com
 
@@ -93,7 +102,62 @@ You can get your API key from http://geocoder.opencagedata.com
 
 Takes a single named parameter 'location' and returns a result hashref.
 
-    my result = $Geocoder->geocode(location => "Mudgee, Australia");
+    my $result = $Geocoder->geocode(location => "Mudgee, Australia");
+
+The OpenCage Geocoder has a few optional parameters, some of which this module
+supports and some of which it doesn't.
+
+=over 1
+
+=item Supported Parameters
+
+=over 2
+
+=item language
+
+An IETF format language code (such as es for Spanish or pt-BR for Brazilian
+Portuguese); if this is omitted a code of en (English) will be assumed.
+
+=item country
+
+Provides the geocoder with a hint to the country that the query resides in.
+This value will help the geocoder but will not restrict the possible results to
+the supplied country.
+
+The country code is a 3 character code as defined by the ISO 3166-1 Alpha 3
+standard.
+
+=back
+
+=item Not Supported
+
+=over 2
+
+=item format
+
+This module only ever uses the JSON format. For other formats you should access
+the API directly using HTTP::Tiny or similar user agent module.
+
+=item jsonp
+
+This module always parses the response as a Perl data structure, so the jsonp
+option is never used.
+
+=item fields
+
+This module always grabs all of the data, and never uses the fields option.
+
+=back
+
+=back
+
+As a full example:
+
+    my $result = $Geocoder->geocode(
+        location => "Псковская улица, Санкт-Петербург, Россия",
+        language => "ru",
+        country => "rus",
+    );
 
 =head1 ENCODING
 
